@@ -2,6 +2,8 @@
 
 context("Testing functions for MFPCAfit class")
 
+pdf(file=NULL) # do not save plots
+
 #### Calculate MFPCA once (see MFPCA help) ####
 set.seed(1)
 ### simulate data (one-dimensional domains)
@@ -151,4 +153,6 @@ test_that("Test screeplot function", {
   
   expect_null(screeplot(pca1D))
   expect_null(screeplot(pca2D))
-})
\ No newline at end of file
+})
+
+dev.off()
\ No newline at end of file
